@@ -82,7 +82,8 @@ def cal_err_mag (I, I_err):
 
 
 def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
-              user_order=None, user_list=None, sky_box=[100, 100],
+              user_order=None, user_list=None, user_claf =None, 
+              sky_box=[100, 100],
               deblend='off', band='R', nsigma=2, npixels=5, dilate_size=11,
               outputfile='properties.dat', eta=0.2, show_plot='yes'):
 
@@ -341,11 +342,14 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
 
     if user_order is None:
         sorta=np.argsort(segm.areas)
+        if user_claf is None:
+            user_claf = np.zeros((len(sorta)))
         for i, gali in enumerate(sorta[::-1]):
 
            morph = source_morphs[gali]
            plot_stat(morph, gal+listl[i], imag, imagm, median_sky_g, area,t, zp,
                          psfg,psf_g, sc_imag, arc_kpc, size_image_phy,
+                         morpht = user_claf[i],
                          outputfile=outputfile, show_plot=show_plot)
 
            data = ascii.read(outputfile)
@@ -370,10 +374,13 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
                print ("")
            ascii.write(data, outputfile, overwrite=True)
     else:
+       if user_claf is None:
+           user_claf = np.zeros((len(user_order)))
        for i, gali in enumerate(user_order):
            morph = source_morphs[gali]
            plot_stat(morph, gal + user_list[i], imag, imagm, median_sky_g, area,
                      t, zp, psfg,psf_g, sc_imag, arc_kpc, size_image_phy,
+                     morpht = user_claf[i],
                      outputfile=outputfile, show_plot=show_plot)
 
            data = ascii.read(outputfile)
@@ -409,7 +416,7 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
                           len(user_order)))
 
 def plot_stat(morph, gal, imag, imagm, median_sky_g, area, t, zp, psfg, psf_g,
-              sc_ima, arc_kpc, size_image_phy, show_plot='yes',
+              sc_ima, arc_kpc, size_image_phy, morpht = 0, show_plot='yes',
               outputfile='properties.dat'):
 
     if os.path.exists(outputfile):
@@ -497,6 +504,10 @@ def plot_stat(morph, gal, imag, imagm, median_sky_g, area, t, zp, psfg, psf_g,
     data['psf_R'][ind] = psf_g
     data['sizep'][ind] = size_image_phy
 
+    data['sizep'][ind] = size_image_phy
+
+    data['morph_type'][ind] = morpht
+
     ascii.write(data, outputfile, overwrite=True)
 
     ny, nx = imag.shape
@@ -1293,8 +1304,8 @@ def plot_simbad(gal, tab_gal, conn, size_image_phy, table, user_order=None,
             #data['dec'][ind] = table['DEC_d'][comp_ind]
             data['radvel'][ind] = table['RV_VALUE'][comp_ind]
             data['z'][ind] = table['Z_VALUE'][comp_ind]
-            data['morph_type'] = data['morph_type'].astype(str)
-            data['morph_type'][ind] = table['MORPH_TYPE'][comp_ind]
+            #data['morph_type'] = data['morph_type'].astype(str)
+            #data['morph_type'][ind] = table['MORPH_TYPE'][comp_ind]
             if itsconsider=='yes':
                 data['Its_considered?'][ind]=1
             if itsconsider=='no':
@@ -1581,7 +1592,7 @@ def ex_phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0,
     if not os.path.exists(path):
         print (f"\nDowloading {path} ...")
         part0 = 'ra={}&dec={}&layer={}&pixscale=0.27&bands={}&size={}'.format(
-             tab_gal['ra'][idg], tab_gal['dec'][idg], band, dr_dic[dr],
+             tab_gal['ra'][idg], tab_gal['dec'][idg],  dr_dic[dr], band,
                      int(size_image))
         targ = home + part0
         print (targ)
